/******************************************************************************
 PSSA_Personalisation.sql 
    - Changes the password for the user called PSSAUser.

YOU!! should edit the password string to be something hard to guess.
Right now the password is xxxxxxxx. 
Change it at the line below with the ****** CHANGE THIS!!!! comment.

This sql file is step 2 of InstallPSSA.bat. 
Step1 (PSSA_Installation.sql) installed the HTM code in Master database and restored the PSSA database.
  
Running the script twice is not hazardous.

Based on SkyServer code written by Cathan Cook (CathanC@microsoft.com) and Jim Gray (Gray@microsoft.com)
Last updated 2004-04-01 by Bob Mann (rgm@roe.ac.uk)

to cleanup
--EXEC sp_dropuser  'PSSAUser'
--exec sp_dropalias 'PSSAUser'
--EXEC sp_droplogin 'PSSAUser'
--EXEC sp_droprole  'PSSAUserRole'
*******************************************************************************/
SET NOCOUNT ON
USE PSSA


DECLARE @defaultpasswd nvarchar(128)
SET @defaultpasswd= 'xxxxxxxx' -- ****** CHANGE THIS!!!! 


PRINT N'************************************************************'
PRINT N'Running PSSA_Personalisation.sql'
PRINT N'************************************************************'
PRINT ''

/********************************************************************/
PRINT ''
PRINT 'Setting up PSSA Security'
/********************************************************************/

/********************************************************************/
-- Add PSSAUserRole role 
/********************************************************************/
IF NOT EXISTS (SELECT N'Role Exists' FROM master..sysusers WHERE name = N'PSSAUserRole')
       BEGIN
	EXEC sp_addrole PSSAUserRole 
 	PRINT 'Added PSSAUserRole role'       
       END
/********************************************************************/
-- Add PSSAUser login
/********************************************************************/
IF NOT EXISTS (SELECT N'Role Exists' FROM master..sysusers WHERE name = N'PSSAUser')
	BEGIN
	  EXEC sp_addlogin 
                 @loginame  = PSSAUSer,
	    	 @passwd    = @defaultpasswd,	
	    	 @defdb     = PSSA 	-- default database
	  PRINT 'Added PSSAUser login' 	      
	END

IF @defaultpasswd = 'xxxxxxxx'
	BEGIN
          PRINT '******* WARNING *******'  
          PRINT ' * IF THIS LINE APPEARS, YOU OBVIOUSLY DID NOT CHANGE THE DEFAULT PASSWORD'
	  PRINT ' * You should edit PSSA_Personalisation.SQL and CHANGE THE DEFAULT PASSWORD!!'
	  PRINT ' * Then, run again InstallPSSA.bat!!'
	END
	
IF NOT EXISTS (SELECT N'User Exists' FROM master..syslogins WHERE name = N'PSSAUser')
  BEGIN
	  EXEC sp_addlogin 
              @loginame  = PSSAUser,
	      @passwd    = @defaultpasswd,	
	      @defdb     = PSSA 	-- default database
	  PRINT 'Added PSSAUser login' 	      
  END
ELSE
  BEGIN
         EXEC sp_password 
		 @old = NULL,
    		 @new = @defaultpasswd,
    		 @loginame = PSSAUser 
         PRINT 'Changed PSSAUser login password' 	      
  END

 
/********************************************************************/
-- Give to PSSAUser user access to this database.
/********************************************************************/
EXEC sp_grantdbaccess PSSAUser
 
/********************************************************************/
-- Add PSSAUser login to SkyServerUser role 
/********************************************************************/
EXEC sp_addrolemember PSSAUserRole, PSSAUser 
EXEC sp_addrolemember db_datareader, PSSAUser 
EXEC sp_change_users_login N'UPDATE_ONE', N'PSSAUser', N'PSSAUser'

/********************************************************************/
-- define spGrantAccess
-- this is a simplified version of the stored procedure in the
-- DR1 version of SkyServer
/********************************************************************/

IF EXISTS (SELECT name FROM   sysobjects 
	WHERE  name = N'spGrantAccess' AND type = 'P')
	DROP PROCEDURE spGrantAccess
GO
--

CREATE PROCEDURE spGrantAccess (@access varchar(20), @user varchar(256))
-------------------------------------------------------------
--/H  spGrantAccess grants access to DB objects
--/A 
--/T <p> parameters:   
--/T <li> access char(1),   		-- U: grant access to dbObjects.access = 'U' objects 
--/T<br>					
--/T					-- A: grant access to all dbObjects
--/T <li> user 	varchar(256),   	-- UserID to grant
--/T <br>
--/T Sample call:<br>
--/T <samp> 
--/T <br> exec  spGrantAccess 'U', 'Test'  
--/T </samp> 
--/T <br>  
------------------------------------------------------------- 
AS
BEGIN
	IF (@access not in ('A', 'U'))
		BEGIN
		PRINT 'Error: spGrantAccess @access parameter must be A or U, it is ' + @access
		RETURN
		END

	DECLARE userObject CURSOR
	READ_ONLY
	FOR 	select name, type
		from sysobjects
		where type in ('P ', 'FN', 'TF', 'TR', 'U ', 'V ', 'X ') 
	  	and status>=0
		 
	
	DECLARE @name varchar(256)
	DECLARE @type char(2)
	DECLARE @verb varchar(32)
	DECLARE @command varchar(1000)
	OPEN userObject
	
	FETCH NEXT FROM userObject INTO @name, @type  
	WHILE (@@fetch_status <> -1)
	BEGIN
	 	IF	(@type in ('U ', 'V ', 'TF'))  SET @verb = 'SELECT' 
		ELSE IF	(@type in ('P ', 'TR', 'FN', 'X '))  SET @verb = 'EXECUTE'
		SET @command = 'GRANT ' + @verb + ' ON ' + @name + ' TO [' + @user +']'
		EXEC (@command)	
		--print @command + ' Type is: ' + @type
		FETCH NEXT FROM userObject INTO @name, @type
		IF (@@fetch_status != 0) BREAK
	END
--	EXEC ('GRANT EXECUTE ON [master].[dbo].xp_varbintohexstr to ['+@user+']')	
	CLOSE userObject
	DEALLOCATE userObject
PRINT 'Access granted all "' + @access + '" objects'
END
GO
---------------------------------


PRINT 'Installed spGrantAccess'
GO




/********************************************************************/
-- Give the role access to the user-visible tables and functions. 
/********************************************************************/
exec  spGrantAccess 'U', 'PSSAUserRole'  
PRINT ''
PRINT 'User read access granted to PSSAUserRole role and to PSSAUser user.'
PRINT ''

/********************************************************************/
PRINT ''
PRINT 'PSSA database restored and personalized.'
PRINT 'Success. '
PRINT '**************************************************************'


PRINT '-----------------------------------------------------' 
PRINT 'TEST YOUR INSTALLATION'
PRINT ''
PRINT 'Use:'   
PRINT '	-  SQL Server authentication'
PRINT '	-  User: PSSAUSer' 
PRINT '	-  Password:  xxxxxxxx or the one you have selected.'
PRINT '	-  Open File: TestPSSAUserAccess.sql'
/********************************************************************/
